==> webCDwriter-2.7.1.tar.bz2: webCDwriter-2.7.1/tools/webCDwriter-installer.sh <==
#!/bin/sh

#
# tools/webCDwriter-installer.sh
#
# This file is part of webCDwriter - Network CD/DVD Writing.
#
# Copyright (C) 2002-2005 Jrg P. M. Haeger
#
# webCDwriter is free software. See CDWserver.cpp for details.
#

# Thanks to Ramon Casha for the "Self-extracting Archive HOWTO"
# (see http://linux.org.mt/article/selfextract)

MD5="@MD5@"
PRODUCT=webCDwriter
PRODUCTDEB=webcdwriter
PORT=12411
RPM=rpm
RPMBUILD=rpmbuild
VERSION=@VERSION@

echo
echo "$PRODUCT $VERSION installer"
echo

while [ -n "$1" ]; do
	case $1 in
	--deb)
		build_deb=yes
		;;
	--help)
		HELP=yes
		;;
	--tar.bz2)
		TARBZ2=yes
		;;
	--tar.gz)
		TARGZ=yes
		;;
	port=?*)
		PORT=`echo $1 | sed "s:port=::g"`
		;;
	*)
		echo $1: unknown argument
		HELP=yes
		;;
	esac
	shift
done

if [ "$HELP" ]; then
	cat <<EOF
Usage: $0 [OPTION]

  --tar.bz2         Create $PRODUCT-$VERSION.tar.bz2 and exit
  --tar.gz          Create $PRODUCT-$VERSION.tar.gz and exit
  port=$PORT        default HTTP port

EOF
	exit 1
fi


SKIP=`awk '/^__ARCHIVE_FOLLOWS__/ { print NR + 1; exit 0; }' $0`

echo -n "Verifying the checksum..."
if [ -x /sbin/md5 ]; then
	# FreeBSD
	MD5TOOL="/sbin/md5 -q"
else
	MD5TOOL=md5sum
fi
MD5test="`tail -n +$SKIP $0 | $MD5TOOL`"
if [ ! "$MD5test" = "$MD5" ]; then
	MD5test="$MD5test  -"
	if [ ! "$MD5test" = "$MD5" ]; then
		echo " does not match -> retry to download this installer!"
		echo
		exit 1
	fi
fi
echo " OK"

if [ "$TARBZ2" ]; then
	echo -n "Creating $PRODUCT-$VERSION.tar.bz2... "
	tail -n +$SKIP $0 > $PRODUCT-$VERSION.tar.bz2
	echo "done"
	exit 0
fi

if [ "$TARGZ" ]; then
	echo -n "Creating $PRODUCT-$VERSION.tar.gz... "
	tail -n +$SKIP $0 | bzip2 -cd - | gzip -c - > $PRODUCT-$VERSION.tar.gz
	echo "done"
	exit 0
fi

echo -n "Has dpkg... "
has_dpkg="no"
if dpkg -L dpkg > /dev/null 2>&1; then
	has_dpkg="yes"
fi
echo "$has_dpkg"

echo -n "Has rpm... "
hasRPM="no"
if rpm -q rpm > /dev/null 2>&1; then
	hasRPM="yes"
fi
echo "$hasRPM"

echo -n "Get the user ID... "
ID=`id -u`
echo "$ID"

if [ ! "$build_deb" ]; then
	KNOPPIX="`grep loop /proc/mounts | grep ' /KNOPPIX '`"
fi

if [ "$ID" = "0" ]; then
	if [ ! "$KNOPPIX" ]; then
		echo
		echo "Do not run \"$0\" as root!"
		echo
		exit 1
	fi
elif [ "$KNOPPIX" ]; then
	echo
	echo "To do:"
	echo
	echo "1. Become root (enter \"su\")"
	echo
	echo "2. Enter \"sh $0\""
	echo
	exit 0
fi

echo -n "Trying to run \"g++ -v\"... "
if g++ -v > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed. Install the \"GNU C++ compiler\"!"
	exit 1
fi

echo -n "Trying to run \"make -v\"... "
if make -v > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed. Install \"GNU Make\"!"
	exit 1
fi

if [ "$has_dpkg" = "yes" ]; then
	echo -n "Trying to run \"dpkg -L dpkg-dev\"... "
	if dpkg -L dpkg-dev > /dev/null 2>&1; then
		echo "OK"
	else
		echo "failed. Enter"
		echo "        sudo apt-get install dpkg-dev debhelper fakeroot"
		echo
		exit 1
	fi

	DEST=$PWD
	DIR=/tmp/$PRODUCT
	rm -rf $DIR/
	mkdir -p $DIR
	tail -n +$SKIP $0 | bzip2 -cd - | gzip -c - > $DIR/${PRODUCTDEB}_$VERSION.orig.tar.gz
	cd $DIR
	tar xzvf ${PRODUCTDEB}_$VERSION.orig.tar.gz
	mv -iv $PRODUCT-$VERSION $PRODUCTDEB-$VERSION
	cd $PRODUCTDEB-$VERSION
	fakeroot dpkg-buildpackage
	RESULT=`ls ../${PRODUCTDEB}_$VERSION-*.deb`
	RESULT=`basename $RESULT`
	mv -iv ../${PRODUCTDEB}_$VERSION-*.deb $DEST/
	echo
	echo "To do:"
	echo
	echo "Install \"$RESULT\" by"
	echo "        sudo dpkg -i $RESULT"
	echo
	exit 0
fi

if [ "$hasRPM" = "no" ]; then
	DIR=/tmp/$PRODUCT
	rm -rf $DIR/
	mkdir -p $DIR
	tail -n +$SKIP $0 > $DIR/$PRODUCT-$VERSION.tar.bz2
	cd $DIR
	tar -xjvf $PRODUCT-$VERSION.tar.bz2
	cd $PRODUCT-$VERSION/
	if [ "$KNOPPIX" ]; then
		UNIONFS="`grep UNIONFS /proc/mounts`"
		if [ ! "$UNIONFS" ]; then
			mv configure configure-orig
			cat configure-orig \
				| sed s*/usr/bin*/var/CDWserver/bin*g \
				| sed s*/usr/sbin*/var/CDWserver/sbin*g \
				> configure
			chmod +x configure
			export PATH=$PATH:/var/CDWserver/bin:/var/CDWserver/sbin
		fi
	fi
	if [ -e /usr/include/security/pam_appl.h ]; then
		PAM="--pam"
	fi
	if [ "$KNOPPIX" ]; then
		./configure --doNotCompileWebCDcreator --group=backup $PAM --port=80
		make
		make install
	else
		./configure --doNotCompileWebCDcreator $PAM --port=$PORT
		CD_STEP="cd $DIR/$PRODUCT-$VERSION" make
	fi
	exit 0
fi

echo -n "Has $RPMBUILD... "
if $RPMBUILD --help > /dev/null 2>&1; then
	echo "yes"
else
	RPMBUILD=$RPM
	echo "no -> will use \"$RPMBUILD -tb\""
fi

echo -n "Trying to run \"$RPM --help\"... "
if $RPM --help > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed"
	exit 1
fi

echo -n "Looking for an already installed $PRODUCT... "
upgrade=0
if $RPM -q $PRODUCT > /dev/null 2>&1; then
	upgrade=1
	installed=`$RPM -q $PRODUCT`
	echo $installed
else
	echo "no"
fi

echo
echo "$PRODUCT $VERSION - building RPM..."
echo

DIR=/tmp/$PRODUCT
rm -rf $DIR/ || exit 1
mkdir -p $DIR/{BUILD,RPMS,SOURCES,SPECS,SRPMS}
tail -n +$SKIP $0 > $DIR/$PRODUCT-$VERSION.tar.bz2
if $RPMBUILD -tb --define "_topdir $DIR/" $DIR/$PRODUCT-$VERSION.tar.bz2; then
	echo
	echo Success
	echo
else
	echo
	echo "I am sorry, but building the RPM failed :-("
	if [ "$RPMBUILD" = "$RPM" ]; then
		echo
		echo "There is no \"rpmbuild\" on your system."
		echo "Ask your package manager (like rpmdrake, yast2, ...) for"
		echo "\"rpm-build\" or a package containing \"/usr/bin/rpmbuild\"."
		echo
	fi
	echo "If you cannot solve the above problem yourself,"
	echo "you may mail the above output to feedback@JoergHaeger.de"
	echo "Perhaps I can refine this installer in a future release ..."
	echo
	exit 1
fi
RESULT=`ls $DIR/RPMS/*/*`
RESULT=`basename $RESULT`
mv -iv $DIR/RPMS/*/* .

echo
echo "To do:"
echo
echo "1. Become root (enter \"su\")"
echo
if [ $upgrade = 0 ]; then
	echo "2. Install $RESULT by"
	echo "        $RPM -ihv $RESULT"
else
	echo "2. Upgrade to $RESULT by"
	echo -n "        $RPM -Uhv"
	if [ "$installed" \> "$RESULT" ]; then
		echo -n " --oldpackage"
	fi
	echo " $RESULT"
fi
echo

exit 0

__ARCHIVE_FOLLOWS__

==> webCDwriter-2.7.3.tar.bz2: webCDwriter-2.7.3/tools/webCDwriter-installer.sh <==
#!/bin/sh

#
# tools/webCDwriter-installer.sh
#
# This file is part of webCDwriter - Network CD/DVD Writing.
#
# Copyright (C) 2002-2005 Jrg P. M. Haeger
#
# webCDwriter is free software. See CDWserver.cpp for details.
#

# Thanks to Ramon Casha for the "Self-extracting Archive HOWTO"
# (see http://linux.org.mt/article/selfextract)

MD5="@MD5@"
PRODUCT=webCDwriter
PRODUCTDEB=webcdwriter
PORT=12411
RPM=rpm
RPMBUILD=rpmbuild
VERSION=@VERSION@

echo
echo "$PRODUCT $VERSION installer"
echo

while [ -n "$1" ]; do
	case $1 in
	--deb)
		build_deb=yes
		;;
	--help)
		HELP=yes
		;;
	--tar.bz2)
		TARBZ2=yes
		;;
	--tar.gz)
		TARGZ=yes
		;;
	port=?*)
		PORT=`echo $1 | sed "s:port=::g"`
		;;
	*)
		echo $1: unknown argument
		HELP=yes
		;;
	esac
	shift
done

if [ "$HELP" ]; then
	cat <<EOF
Usage: $0 [OPTION]

  --tar.bz2         Create $PRODUCT-$VERSION.tar.bz2 and exit
  --tar.gz          Create $PRODUCT-$VERSION.tar.gz and exit
  port=$PORT        default HTTP port

EOF
	exit 1
fi


SKIP=`awk '/^__ARCHIVE_FOLLOWS__/ { print NR + 1; exit 0; }' $0`

echo -n "Verifying the checksum..."
if [ -x /sbin/md5 ]; then
	# FreeBSD
	MD5TOOL="/sbin/md5 -q"
else
	MD5TOOL=md5sum
fi
MD5test="`tail -n +$SKIP $0 | $MD5TOOL`"
if [ ! "$MD5test" = "$MD5" ]; then
	MD5test="$MD5test  -"
	if [ ! "$MD5test" = "$MD5" ]; then
		echo " does not match -> retry to download this installer!"
		echo
		exit 1
	fi
fi
echo " OK"

if [ "$TARBZ2" ]; then
	echo -n "Creating $PRODUCT-$VERSION.tar.bz2... "
	tail -n +$SKIP $0 > $PRODUCT-$VERSION.tar.bz2
	echo "done"
	exit 0
fi

if [ "$TARGZ" ]; then
	echo -n "Creating $PRODUCT-$VERSION.tar.gz... "
	tail -n +$SKIP $0 | bzip2 -cd - | gzip -c - > $PRODUCT-$VERSION.tar.gz
	echo "done"
	exit 0
fi

echo -n "Has dpkg... "
has_dpkg="no"
if dpkg -L dpkg > /dev/null 2>&1; then
	has_dpkg="yes"
fi
echo "$has_dpkg"

echo -n "Has rpm... "
hasRPM="no"
if rpm -q rpm > /dev/null 2>&1; then
	hasRPM="yes"
fi
echo "$hasRPM"

echo -n "Get the user ID... "
ID=`id -u`
echo "$ID"

if [ ! "$build_deb" ]; then
	KNOPPIX="`grep loop /proc/mounts | grep ' /KNOPPIX '`"
fi

if [ "$ID" = "0" ]; then
	if [ ! "$KNOPPIX" ]; then
		echo
		echo "Do not run \"$0\" as root!"
		echo
		exit 1
	fi
elif [ "$KNOPPIX" ]; then
	echo
	echo "To do:"
	echo
	echo "1. Become root (enter \"su\")"
	echo
	echo "2. Enter \"sh $0\""
	echo
	exit 0
fi

echo -n "Trying to run \"g++ -v\"... "
if g++ -v > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed. Install the \"GNU C++ compiler\"!"
	exit 1
fi

echo -n "Trying to run \"make -v\"... "
if make -v > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed. Install \"GNU Make\"!"
	exit 1
fi

if [ "$has_dpkg" = "yes" ]; then
	echo -n "Trying to run \"dpkg -L dpkg-dev\"... "
	if dpkg -L dpkg-dev > /dev/null 2>&1 \
			&& dpkg -L fakeroot > /dev/null 2>&1; then
		echo "OK"
	else
		echo "failed. Enter"
		echo
		echo "        sudo apt-get install dpkg-dev debhelper fakeroot"
		echo
		exit 1
	fi

	DEST=$PWD
	DIR=/tmp/$PRODUCT
	rm -rf $DIR/
	mkdir -p $DIR
	tail -n +$SKIP $0 | bzip2 -cd - | gzip -c - > $DIR/${PRODUCTDEB}_$VERSION.orig.tar.gz
	cd $DIR
	tar xzvf ${PRODUCTDEB}_$VERSION.orig.tar.gz
	mv -iv $PRODUCT-$VERSION $PRODUCTDEB-$VERSION
	cd $PRODUCTDEB-$VERSION
	fakeroot dpkg-buildpackage
	RESULT=`ls ../${PRODUCTDEB}_$VERSION-*.deb`
	RESULT=`basename $RESULT`
	mv -iv ../${PRODUCTDEB}_$VERSION-*.deb $DEST/
	echo
	echo "To do:"
	echo
	echo "Install \"$RESULT\" by"
	echo "        sudo dpkg -i $RESULT"
	echo
	exit 0
fi

if [ "$hasRPM" = "no" ]; then
	DIR=/tmp/$PRODUCT
	rm -rf $DIR/
	mkdir -p $DIR
	tail -n +$SKIP $0 > $DIR/$PRODUCT-$VERSION.tar.bz2
	cd $DIR
	tar -xjvf $PRODUCT-$VERSION.tar.bz2
	cd $PRODUCT-$VERSION/
	if [ "$KNOPPIX" ]; then
		UNIONFS="`grep UNIONFS /proc/mounts`"
		if [ ! "$UNIONFS" ]; then
			mv configure configure-orig
			cat configure-orig \
				| sed s*/usr/bin*/var/CDWserver/bin*g \
				| sed s*/usr/sbin*/var/CDWserver/sbin*g \
				> configure
			chmod +x configure
			export PATH=$PATH:/var/CDWserver/bin:/var/CDWserver/sbin
		fi
	fi
	if [ -e /usr/include/security/pam_appl.h ]; then
		PAM="--pam"
	fi
	if [ "$KNOPPIX" ]; then
		./configure --doNotCompileWebCDcreator --group=backup $PAM --port=80
		make
		make install
	else
		./configure --doNotCompileWebCDcreator $PAM --port=$PORT
		CD_STEP="cd $DIR/$PRODUCT-$VERSION" make
	fi
	exit 0
fi

echo -n "Has $RPMBUILD... "
if $RPMBUILD --help > /dev/null 2>&1; then
	echo "yes"
else
	RPMBUILD=$RPM
	echo "no -> will use \"$RPMBUILD -tb\""
fi

echo -n "Trying to run \"$RPM --help\"... "
if $RPM --help > /dev/null 2>&1; then
	echo "OK"
else
	echo "failed"
	exit 1
fi

echo -n "Looking for an already installed $PRODUCT... "
upgrade=0
if $RPM -q $PRODUCT > /dev/null 2>&1; then
	upgrade=1
	installed=`$RPM -q $PRODUCT`
	echo $installed
else
	echo "no"
fi

echo
echo "$PRODUCT $VERSION - building RPM..."
echo

DIR=/tmp/$PRODUCT
rm -rf $DIR/ || exit 1
mkdir -p $DIR/{BUILD,RPMS,SOURCES,SPECS,SRPMS}
tail -n +$SKIP $0 > $DIR/$PRODUCT-$VERSION.tar.bz2
if $RPMBUILD -tb --define "_topdir $DIR/" $DIR/$PRODUCT-$VERSION.tar.bz2; then
	echo
	echo Success
	echo
else
	echo
	echo "I am sorry, but building the RPM failed :-("
	if [ "$RPMBUILD" = "$RPM" ]; then
		echo
		echo "There is no \"rpmbuild\" on your system."
		echo "Ask your package manager (like rpmdrake, yast2, ...) for"
		echo "\"rpm-build\" or a package containing \"/usr/bin/rpmbuild\"."
		echo
	fi
	echo "If you cannot solve the above problem yourself,"
	echo "you may mail the above output to feedback@JoergHaeger.de"
	echo "Perhaps I can refine this installer in a future release ..."
	echo
	exit 1
fi
RESULT=`ls $DIR/RPMS/*/*`
RESULT=`basename $RESULT`
mv -iv $DIR/RPMS/*/* .

echo
echo "To do:"
echo
echo "1. Become root (enter \"su\")"
echo
if [ $upgrade = 0 ]; then
	echo "2. Install $RESULT by"
	echo "        $RPM -ihv $RESULT"
else
	echo "2. Upgrade to $RESULT by"
	echo -n "        $RPM -Uhv"
	if [ "$installed" \> "$RESULT" ]; then
		echo -n " --oldpackage"
	fi
	echo " $RESULT"
fi
echo

exit 0

__ARCHIVE_FOLLOWS__
